@@ -12,6 +12,8 @@ import argparse
 import json
 import codecs
 
+from numpy import unicode_
+
 import linkrot
 from linkrot.downloader import check_refs
 
@@ -19,7 +21,7 @@ from linkrot.downloader import check_refs
 IS_PY2 = sys.version_info < (3, 0)
 if IS_PY2:
     # Python 2
-    parse_str = unicode  # noqa: F821
+    parse_str = unicode_
 else:
     # Python 3
     parse_str = str
@@ -121,11 +123,12 @@ def create_parser():
 def get_text_output(pdf, args):
     """ Normal output of infos of linkrot instance """
     # Metadata
-    ret = ""
-    ret += "Document infos:\n"
-    for k, v in sorted(pdf.get_metadata().items()):
-        if v:
-            ret += "- %s = %s\n" % (k, parse_str(v).strip("/"))
+    # ret = ""
+    # ret += "Document infos:\n"
+    # print(pdf.get_metadata()[None])
+    # for k, v in sorted(pdf.get_metadata().items()):
+    #     if v:
+    #         ret += "- %s = %s\n" % (k, parse_str(v).strip("/"))
 
     # References
     ref_cnt = pdf.get_references_count()
